@@ -12,9 +12,12 @@
 #   This script is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# $Id: Cannabinol.pm,v 1.3 2001/09/05 19:48:15 dave Exp $
+# $Id: Cannabinol.pm,v 1.4 2001/12/09 19:12:54 dave Exp dave $
 #
 # $Log: Cannabinol.pm,v $
+# Revision 1.4  2001/12/09 19:12:54  dave
+# Added Attribute::Handlers interface.
+#
 # Revision 1.3  2001/09/05 19:48:15  dave
 # fixed a very serious bug where instead of returning a random value from the hash we were, in fact, almost always returning C<undef>.
 #
@@ -30,8 +33,9 @@ package Tie::Hash::Cannabinol;
 use strict;
 use vars qw($VERSION @ISA);
 use Tie::Hash;
+use Attribute::Handlers autotie => { __CALLER__::Stoned => __PACKAGE__ };
 
-$VERSION = sprintf "%d.%02d", '$Revision: 1.3 $ ' =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", '$Revision: 1.4 $ ' =~ /(\d+)\.(\d+)/;
 @ISA = qw(Tie::StdHash);
 
 # Preloaded methods go here.
@@ -71,9 +75,14 @@ Tie::Hash::Cannabinol - Perl extension for creating hashes that forget things
   my %hash;
   tie %hash, 'Tie::Hash::Cannabinol';
 
+or
+
+  my %hash : Stoned;
+
   # % hash can now be treated exactly like a normal hash - but don't trust
   # anything it tells you.
 
+
 =head1 DESCRIPTION
 
 Tie::Hash::Cannabinol is a completely useless demonstration of how to use
